@@ -7,7 +7,7 @@ import random
 import signal
 import time
 
-from instabot import utils
+from gain_with_hashi import utils
 
 # from instabot.api.api import API
 from ..api import API
@@ -486,11 +486,15 @@ class Bot(object):
         Sleep only if elapsed time since
         `self.last[key]` < `self.delay[key]`.
         """
+
         last_action, target_delay = self.last[key], self.delays[key]
         elapsed_time = time.time() - last_action
+        # print("elapsed_time: ",elapsed_time)
         if elapsed_time < target_delay:
             t_remaining = target_delay - elapsed_time
-            time.sleep(t_remaining * random.uniform(0.25, 1.25))
+            # print("t_remaining: ",t_remaining)
+            time.sleep(10 * random.uniform(0.75, 1.25))
+            # time.sleep(10)
         self.last[key] = time.time()
 
     def error_delay(self):
